@@ -5,6 +5,7 @@ Implements a sweeper plugin for Orion.
 import logging
 import os
 import re
+import uuid
 from collections import defaultdict
 from contextlib import contextmanager
 from copy import deepcopy
@@ -41,6 +42,7 @@ logger = logging.getLogger(__name__)
 
 NESTED_DIM_REGEX = re.compile(r"[A-Za-z0-9]*(\.[A-Za-z0-9]*)+=.*")
 
+
 # pylint: disable=too-few-public-methods
 class SpaceFunction:
     """Type to recognize orion functions parsed by the override parser"""
@@ -158,11 +160,18 @@ def override_parser():
     return parser
 
 
-def as_overrides(trial, additional):
+def as_overrides(trial, additional, uuid):
     """Returns the trial arguments as hydra overrides"""
     kwargs = deepcopy(additional)
     kwargs.update(flatten(trial.params))
-    return tuple(f"{k}={v}" for k, v in kwargs.items())
+
+    args = [f"{k}={v}" for k, v in kwargs.items()]
+    args += [
+        f"hydra.sweeper.experiment.id={trial.experiment}",
+        f"hydra.sweeper.experiment.trial={trial.id}",
+        f"hydra.sweeper.experiment.uuid={uuid}",
+    ]
+    return tuple(args)
 
 
 def to_objective(value):
@@ -324,13 +333,13 @@ def clientctx(client):
         client.close()
 
 
-# pylint: disable=too-many-public-methods
+# pylint: disable=too-many-public-methods,too-many-instance-attributes
 class OrionSweeperImpl(Sweeper):
     """Implementation of the orion Sweeper"""
 
     def __init__(
         self,
-        orion: OrionClientConf,
+        experiment: OrionClientConf,
         worker: WorkerConf,
         algorithm: AlgorithmConf,
         storage: StorageConf,
@@ -341,8 +350,9 @@ class OrionSweeperImpl(Sweeper):
         self.pending_trials = set()
         self.client = None
         self.storage = None
+        self.uuid = uuid.uuid1().hex
 
-        self.orion_config = orion
+        self.orion_config = experiment
         self.worker_config = worker
         self.algo_config = algorithm
         self.storage_config = storage
@@ -526,7 +536,7 @@ class OrionSweeperImpl(Sweeper):
     def execute_trials(self, trials: List[Trial]) -> Sequence[JobReturn]:
         """Execture the given batch of trials"""
 
-        overrides = list(as_overrides(t, self.arguments) for t in trials)
+        overrides = list(as_overrides(t, self.arguments, self.uuid) for t in trials)
         self.validate_batch_is_legal(overrides)
 
         returns = self.launcher.launch(overrides, initial_job_idx=self.job_idx)
@@ -577,12 +587,15 @@ class OrionSweeperImpl(Sweeper):
 
         best_params = self.client.get_trial(uid=results.best_trials_id).params
 
+        print(results)
         results = asdict(results)
         results["name"] = "orion"
         results["best_evaluated_params"] = best_params
         results["start_time"] = str(results["start_time"])
         results["finish_time"] = str(results["finish_time"])
-        results["duration"] = str(results["duration"])
+        results["elapsed_time"] = str(results.get("elapsed_time", 0))
+        results["sum_of_trials_time"] = str(results.get("sum_of_trials_time", 0))
+        results["eta"] = str(results.get("eta", 0))
 
         OmegaConf.save(
             OmegaConf.create(results),
